@@ -13,7 +13,7 @@ from maxmind.geoip import test_maxmind_geoip
 from eurosatory.crawler import test_eurosatory
 from dcinside.crawler import test_dcinside_crawler
 from exposeguridadmexico.crawler import test_expo_guarid
-from coupang.reviews import test_coupang_review
+from coupang.reviews import crawl_coupang_review
 
 
 def main():
@@ -75,7 +75,7 @@ def main():
         test_expo_guarid()
 
     if args.appname == 'coupang':
-        test_coupang_review()
+        crawl_coupang_review(page_range=(2, 2))
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
