@@ -1,4 +1,4 @@
-from .crawler import crawl_naver_place
+from .place import crawl_naver_place
 
 
 places = [
